@@ -27,7 +27,7 @@ def load_file(filename: str) -> str:
         return str(f.read())
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def fixture_tmpdir():
     tmpdir = str(mkdtemp(suffix=".ninja.tests"))
     yield tmpdir
@@ -51,3 +51,16 @@ def fixture_mktmpfile(tmp_path_factory):
         return fn_file
 
     return _mktmpfile
+
+
+@pytest.fixture
+def fixture_recursion_depth_100(scope="function"):
+    """
+    Temporarily lowers the recursionlimit to 100
+    """
+    import sys
+
+    sys_recursionlimit = sys.getrecursionlimit()
+    sys.setrecursionlimit(100)
+    yield
+    sys.setrecursionlimit(sys_recursionlimit)
